import { transformError as sdkTransformError } from '@wix/sdk-runtime/transform-error';
import { renameKeysFromSDKRequestToRESTRequest } from '@wix/sdk-runtime/rename-all-nested-keys';
import * as ambassadorWixDevcenterBiEventsV1SendBiEventResponse from './devcenter-bi-events-v1-send-bi-event-response-bi-events.http.js';
export var EventName;
(function (EventName) {
    /** Unknown event name. */
    EventName["UNKNOWN"] = "UNKNOWN";
    /** A site owner or contributor loads your app's dashboard. */
    EventName["APP_DASHBOARD_LOADED"] = "APP_DASHBOARD_LOADED";
    /** The site owner completes all required configurations for your app in your app's dashboard. */
    EventName["APP_FINISHED_CONFIGURATION"] = "APP_FINISHED_CONFIGURATION";
    /** The site owner upgrades your app's paid plan. An upgrade means that they have finished the checkout flow on the app's side but not necessarily on Wix's side. */
    EventName["APP_UPGRADED"] = "APP_UPGRADED";
    /** A site owner, contributor, or visitor triggers your app's primary action. For example, a site visitor writes a product review using your product review app. */
    EventName["PRIMARY_ACTION_PERFORMED"] = "PRIMARY_ACTION_PERFORMED";
    /** Any event that's not listed here. Make sure to also send `customEventName`. */
    EventName["CUSTOM"] = "CUSTOM";
    /** You charge money from the site owner. For example, when the site owner purchases or renews a subscription for your app. Make sure to also send `eventData` and a key of `sum`. */
    EventName["CHARGE"] = "CHARGE";
    /** Trigger this event when you send money back to a site owner (for example, refunds or chargebacks). Make sure to also send the charge amount inside `eventData`. For example, `{"eventData": {"sum": "5.99"}}`. */
    EventName["FUNDS_RETURNED"] = "FUNDS_RETURNED";
    /** __Deprecation Notice:__ This enum value will be removed on March 30, 2023. Use `"APP_SETUP_FINISHED"` instead. */
    EventName["APP_FINISH_BUSINESS_SETUP"] = "APP_FINISH_BUSINESS_SETUP";
    /** Your app’s internal code implementation is changed and might affect user flows or cause a regression. */
    EventName["APP_DEPLOYED"] = "APP_DEPLOYED";
    /** The site owner completes your app's required business setup. */
    EventName["APP_SETUP_FINISHED"] = "APP_SETUP_FINISHED";
})(EventName || (EventName = {}));
/**
 * Submit a BI event to Wix.
 * @public
 * @permissionId WIX_DEVELOPERS.SEND_BI_EVENTS
 * @permissionScope Manage Your App
 * @permissionScopeId SCOPE.DC.MANAGE-YOUR-APP
 * @permissionScope Read site, business, and email details
 * @permissionScopeId SCOPE.DEV_CENTER.APP-INSTANCE-READ-BASIC-INFO
 * @applicableIdentity APP
 * @fqn com.wixpress.market.aim.api.BIEventsService.sendBIEvent
 */
export async function sendBiEvent(options) {
    // @ts-ignore
    const { httpClient, sideEffects } = arguments[1];
    const payload = renameKeysFromSDKRequestToRESTRequest({
        eventName: options?.eventName,
        customEventName: options?.customEventName,
        eventData: options?.eventData,
    });
    const reqOpts = ambassadorWixDevcenterBiEventsV1SendBiEventResponse.sendBiEvent(payload);
    sideEffects?.onSiteCall?.();
    try {
        const result = await httpClient.request(reqOpts);
        sideEffects?.onSuccess?.(result);
    }
    catch (err) {
        const transformedError = sdkTransformError(err, {
            spreadPathsToArguments: {},
            explicitPathsToArguments: {
                eventName: '$[0].eventName',
                customEventName: '$[0].customEventName',
                eventData: '$[0].eventData',
            },
            singleArgumentUnchanged: false,
        }, ['options']);
        sideEffects?.onError?.(err);
        throw transformedError;
    }
}
//# sourceMappingURL=devcenter-bi-events-v1-send-bi-event-response-bi-events.universal.js.map